<?php # -*- coding: utf-8 -*-
/**
 * Plugin Name: MultilingualPress Addon: Nav Menu Icons
 * Plugin URI:  http://make.marketpress.com/multilingualpress/?p=167
 * Description: Adds icons to language items in the nav menu.
 * Version:     17.10.14
 * Required:    4.0
 * Author:      Inpsyde GmbH, Thomas Scholz
 * Author URI:  http://marketpress.com/
 * License:     GPL
 */


/**
 * Adds an icon to the menu text
 *
 * $item is passed as an object handle, so this function can change it
 * directly and doesn't have to return anything.
 * We still return a string value to make unit tests easier.
 *
 * @link    http://make.marketpress.com/multilingualpress/?p=167
 * @wp-hook mlp_prepare_nav_menu_item_output
 * @param   WP_Post                        $item
 * @param   Mlp_Translation_Interface|NULL $translation Might be NULL
 *                       if there is no translation for the item or
 *                       the other site is not linked to the current
 *                       site.
 * @return  string  When and why we stopped.
 */
function mlp_add_icons_to_menu( WP_Post $item, $translation = NULL ) {

	if ( ! is_object( $translation ) )
		return 'no translation object';

	if ( ! class_implements( $translation, 'Mlp_Translation_Interface' ) )
		return 'invalid translation object';

	if ( FALSE !== strpos( $item->title, '<img' ) )
		return 'icon already present';

	/* $translation->get_icon_url() returns an instance of
	 * Mlp_Url_Interface, so we have to cast it to a string
	 * before we check it with empty().
	 * @see Mlp_Url_Interface
	 */
	$icon_url = (string) $translation->get_icon_url();

	if ( empty ( $icon_url ) )
		return 'no icon available';

	$item->title = "<img src='$icon_url' alt=''> $item->title";

	return 'success';
}

add_action(
	'mlp_prepare_nav_menu_item_output', // hook
	'mlp_add_icons_to_menu',            // callback
	10,                                 // priority
	2                                   // number of accepted arguments
);